<?php
add_action('template_redirect', 'websitez_is_mobile', 1);

if(!function_exists("websitez_is_mobile")):
	function websitez_is_mobile(){
		global $wp_query;
		if(is_object($wp_query)):
			$websitez_mobile_device = websitez_get_mobile_device();
			if($websitez_mobile_device['status'] || $websitez_mobile_device['status'] == "true")
				$is_mobile = true;
			else
				$is_mobile = false;
	    $wp_query->query_vars['is_mobile'] = $is_mobile;
	    $wp_query->query_vars['device_details'] = $websitez_mobile_device['details'];
    endif;
	}
endif;

function websitez_get_mobile_device(){
	global $websitez_mobile_device;
	return $websitez_mobile_device;
}
function websitez_set_mobile_device($mobile_device){
	global $websitez_mobile_device;
	$websitez_mobile_device = $mobile_device;
}
/*
Insert proper meta tags for caching and attribution
*/
function websitez_wordpress_generator($generator) {
	$headers = "\n";
	$headers .= '<meta http-equiv="Cache-Control" content="max-age=200" />';
	$headers .= "\n";
	$headers .= '<meta name="generator" content="WordPress ' . get_bloginfo( 'version' ) . ' - Mobile Detection by '.WEBSITEZ_PLUGIN_NAME.'" />';
	$headers .= "\n";
  return $headers;
}
/*
Send header to let them requester know that it was mobilized
*/
function websitez_send_headers($wp) {
  @header("X-Mobilized-By: ".WEBSITEZ_PLUGIN_NAME);
}

/*
This will style a dynamic sidebar if one is created by the website owner
*/
function websitez_reclamation_sidebar_params($params){
	$params[0]['before_widget'] = '<div class="wrapper"><div class="ui-body ui-body-f"><div data-role="collapsible" data-theme="a">';
	$params[0]['before_title'] = '<h3>';
	if($params[0]['widget_name'] == "Calendar" || $params[0]['widget_name'] == "Text" || $params[0]['widget_name'] == "Tag Cloud"){
		$params[0]['after_title'] = '</h3><p>';
		$params[0]['after_widget'] = '</p></div></div></div>';
	}else{
		$params[0]['after_title'] = '</h3><ul data-role="listview" data-inset="true" data-theme="c">';
		$params[0]['after_widget'] = '</ul></div></div></div>';
	}
	
	return $params;
} 
/*
This is called on activation of the plugin
*/
function websitez_install(){
	global $wpdb, $websitez_free_version, $websitez_unlimited_version, $websitez_preinstalled_templates, $table_prefix;
	
	//Always ping on installation
	$token = $_SERVER['HTTP_HOST'];
	//$requested_page = file_get_contents("http://websitez.com/authorize.php?token=".rawurlencode($token));
	$requested_page = websitez_remote_request("http://websitez.com/authorize.php","token=".rawurlencode($token));
	$authorization = unserialize($requested_page);
	
	/*
	Insert the proper values into the db
	*/
	if($websitez_free_version == true || ($authorization['status'] == "1" || $websitez_unlimited_version == true)){
		/*
		Setup the stats table to record mobile visits
		*/
		$table_name = WEBSITEZ_STATS_TABLE;
		if($wpdb->get_var("show tables like '$table_name'") != $table_name) {
			$sql = "CREATE TABLE " . $table_name . " (
				id int(11) NOT NULL AUTO_INCREMENT,
				data text NOT NULL,
				device_type int(2) NOT NULL,
				created_at DATETIME NOT NULL,
				UNIQUE KEY id (id),
				PRIMARY KEY(created_at)
				);";
		
		  require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		  dbDelta($sql);
		}
		
		//Default options for the customizable mobile theme
		$websitez_options = array(
			'colors' => array(
				"custom_color_light"=>"4f7498",
				"custom_color_medium_light"=>"abbdce",
				"custom_color_dark"=>"3c5975",
				"default_link_color"=>"3c5975",
				"custom_post_background"=>"ffffff",
				"custom_header_logo"=>"f5f5f5"
			),
			'general' => array(
				"mobile_home_page"=>"posts",
				"selected_mobile_theme"=>"websitez-mobile",
				"posts_per_page"=>"",
				"display_to_tablet"=>"yes"
			),
			'analytics' => array(
				"show_analytics"=>"no",
				"show_analytics_snippet"=>""
			),
			'ads' => array(
				"show_header"=>"no",
				"show_header_snippet"=>"",
				"show_footer"=>"no",
				"show_footer_snippet"=>""
			),
			'images' => array(
				"header_left_icon"=>"images/ico/1_shirts.png",
				"custom_website_background"=>"images/bg.gif",
				"logo"=>""
			),
			'sidebar' => array(
				"menu_order"=>"show_search_div,show_menu_div,show_pages_div,show_categories_div,show_blogroll_div,show_meta_div",
				"show_menu"=>"yes",
				"show_pages"=>"yes",
				"show_pages_items"=>"",
				"show_categories"=>"yes",
				"show_categories_items"=>"",
				"show_blogroll"=>"yes",
				"show_blogroll_items"=>"",
				"show_meta"=>"yes",
				"show_search"=>"yes"
			)
		);
		
		//Set the default options if they do not exist
		if(!get_option("websitez-options"))
			add_option("websitez-options", serialize($websitez_options), '', 'yes');
		else
			update_option("websitez-options", serialize($websitez_options));
			
		if(!get_option(WEBSITEZ_DISABLE_PLUGIN_NAME))
			add_option(WEBSITEZ_DISABLE_PLUGIN_NAME, WEBSITEZ_DISABLE_PLUGIN, '', 'false');
		
		if(!get_option(WEBSITEZ_RECORD_STATS_NAME))
			add_option(WEBSITEZ_RECORD_STATS_NAME, WEBSITEZ_RECORD_STATS, '', 'yes');
		
		if(!get_option(WEBSITEZ_REDIRECT_MOBILE_VISITORS_NAME))
			add_option(WEBSITEZ_REDIRECT_MOBILE_VISITORS_NAME, WEBSITEZ_REDIRECT_MOBILE_VISITORS, '', 'false');
		
		if(!get_option(WEBSITEZ_REDIRECT_MOBILE_VISITORS_WEBSITE_NAME))
			add_option(WEBSITEZ_REDIRECT_MOBILE_VISITORS_WEBSITE_NAME, WEBSITEZ_REDIRECT_MOBILE_VISITORS_WEBSITE, '', '');
		
		if(!get_option(WEBSITEZ_USE_PREINSTALLED_THEMES_NAME))
			add_option(WEBSITEZ_USE_PREINSTALLED_THEMES_NAME, WEBSITEZ_USE_PREINSTALLED_THEMES, '', 'yes');
		
		if(!get_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME))
			add_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME, WEBSITEZ_SHOW_ATTRIBUTION, '', 'yes');

		if(!get_option(WEBSITEZ_ADVANCED_THEME)){
			if(WEBSITEZ_USE_PREINSTALLED_THEMES == "true")
				add_option(WEBSITEZ_ADVANCED_THEME, WEBSITEZ_INSTALL_ADVANCED_THEME, '', 'yes');
			else
				add_option(WEBSITEZ_ADVANCED_THEME, WEBSITEZ_DEFAULT_THEME, '', 'yes');
		}
	}else{
		if(strlen($authorization['message']) > 0)
			exit($authorization['message']);
		else
			exit("There was an error activating the plugin. Please try again.");
	}
}

/*
Remove all traces of the plugin
This is not currently in use, but may be implemented TODO
*/
function websitez_uninstall(){
	global $wpdb;
	if(get_option(WEBSITEZ_ADVANCED_THEME))
		delete_option(WEBSITEZ_ADVANCED_THEME);
	if(get_option(WEBSITEZ_RECORD_STATS_NAME))
		delete_option(WEBSITEZ_RECORD_STATS_NAME);
	
	$table_name = WEBSITEZ_STATS_TABLE;//TODO
	if($wpdb->get_var("show tables like '$table_name'") == $table_name) {
		$sql = "DROP TABLE ".$table_name;
		require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
		dbDelta($sql);
	}
}

/*
Start the buffer to filter the raw contents of a page
*/
function websitez_basic_buffer(){
	//Don't filter Dashboard pages and the feed
	if (is_feed() || is_admin()){
		return;
	}

	ob_start("websitez_filter_basic_page");
}

/*
Start the buffer to filter the raw contents of a page
*/
function websitez_advanced_buffer(){
	//Don't filter Dashboard pages and the feed
	if (is_feed() || is_admin()){
		return;
	}
	
	ob_start("websitez_filter_advanced_page");
}

/*
Filter content for an advanced mobile device
*/
function websitez_filter_advanced_page($html){
	global $requestingDevice;
	if (class_exists('DOMDocument')) {
		try{
			//This is the WURFL object
			$websitez_mobile_device = websitez_get_mobile_device();
			//Resize the images on the page
			$dom = new DOMDocument();
			$dom->loadHTML($html);
			
			// grab all the on the page and make sure they are the right size
			$xpath = new DOMXPath($dom);
			$imgs = $xpath->evaluate("/html/body//img");
			
			for ($i = 0; $i < $imgs->length; $i++) {
				/*$img = $imgs->item($i);
				$src = trim($img->getAttribute('src'));
				$img->removeAttribute('width');
				$img->removeAttribute('height');
				//Use dynamic image resizer link
				if(strlen($src) > 0){
					$ext = substr(strrchr($src, '.'), 1);
					if($requestingDevice->getCapability($ext) == "true"):
						$max_image_width = (Int)$requestingDevice->getCapability('resolution_width');
						if($max_image_width > 0):
							$max_width = $max_image_width;
						else:
							$max_width = WEBSITEZ_ADVANCED_MAX_IMAGE_WIDTH;
						endif;
	
						list($width, $height) = getimagesize($src);
						$blog_url = get_bloginfo('siteurl');
						if($width > $max_width):
							if(stripos($src,$blog_url) !== false):
								$arr = explode("/",$src);
								if(count($arr) > 4):
									unset($arr[0]);
									unset($arr[1]);
									unset($arr[2]);
									$src = "/".implode("/",$arr);
								endif;
							endif;
							$tmp = parse_url($src);
							if(strlen($tmp['host']) > 0):
								$path = $tmp['scheme']."://".$tmp['host'].$tmp['path'];
							else:
								$path = $tmp['path'];
							endif;
							$resize = plugin_dir_url(__FILE__)."/timthumb.php?src=".urlencode($path)."&w=".$max_width;
							$img->setAttribute('src', $resize);
						endif;
					else:
						$img->setAttribute('src', '');
					endif;
				}*/
			}
			
			/*if($requestingDevice->getCapability('video') != "true"): //Remove all videos
				$videos = $xpath->evaluate("/html/body//video");
				for ($i = 0; $i < $videos->length; $i++) {
					$videos->item($i)->parentNode->removeChild($videos->item($i));
				}
			elseif($requestingDevice->getCapability('video') == "true"): //Resize all videos
				$videos = $xpath->evaluate("/html/body//video");
				for ($i = 0; $i < $videos->length; $i++) {
					$max_vid_width = (Int)$requestingDevice->getCapability('resolution_width');
					if($max_vid_width > 0):
						$max_width = $max_vid_width;
					else:
						$max_width = WEBSITEZ_ADVANCED_MAX_IMAGE_WIDTH;
					endif;
					
					$vid = $videos->item($i);
					$width = $vid->getAttribute('width');
					if($width == "" || (Int)$width > $max_width):
						$vid->setAttribute('width', $max_width);
					endif;
				}
			endif;
			
			$audios = $xpath->evaluate("/html/body//audio");
			for ($i = 0; $i < $audios->length; $i++) {
				$audio = $audios->item($i);
				$src = $audio->getAttribute('src');
				$ext = substr(strrchr($src, '.'), 1);
				if($requestingDevice->getCapability($ext) != "true"):
					$audios->item($i)->parentNode->removeChild($audios->item($i));
				endif;
			}
			
			$objects = $xpath->evaluate("/html/body//object");
			for ($i = 0; $i < $objects->length; $i++) {
				$object = $objects->item($i);
				$type = $object->getAttribute('type');
				$data = $object->getAttribute('data');
				//Flash
				if(stripos($type,"flash") !== false || stripos($data,".swf") !== false || stripos($data,".fla") !== false):
					if($requestingDevice->getCapability('full_flash_support') != "true"):
						$objects->item($i)->parentNode->removeChild($objects->item($i));
					endif;
				endif;
			}
			
			$scripts = $xpath->evaluate("/html//script");
			for ($i = 0; $i < $scripts->length; $i++) {
				$script = $scripts->item($i);
				$type = $script->getAttribute('type');
				if(stripos($type,"javascript") !== false):
					if($requestingDevice->getCapability('ajax_support_javascript') != "true"):
						$scripts->item($i)->parentNode->removeChild($scripts->item($i));
					endif;
				endif;
			}
			
			$params = $xpath->evaluate("/html/body//param");
			for ($i = 0; $i < $params->length; $i++) {
				$param = $params->item($i);
				$data = $param->getAttribute('value');
				//Flash
				if(stripos($data,".swf") !== false || stripos($data,".fla") !== false):
					if($requestingDevice->getCapability('full_flash_support') != "true"):
						$params->item($i)->parentNode->parentNode->removeChild($params->item($i)->parentNode);
					endif;
				endif;
			}*/
			
			$stuff = $dom->saveHTML();
		}catch(Exception $e){
			$stuff = $html;
		}
	}else{
		$stuff = $html;
	}
	
	return $stuff;
}

/*
Filter content for a basic mobile device
*/
function websitez_filter_basic_page($html){
	global $websitez_preinstalled_templates;

	if (class_exists('DOMDocument')) {
		try{
			//Resize the images on the page
			$dom = new DOMDocument();
			$dom->loadHTML($html);
			
			// grab all the on the page and make sure they are the right size
			$xpath = new DOMXPath($dom);
			$divs = $xpath->evaluate("/html/body//div");
			
			for ($i = 0; $i < $divs->length; $i++) {
				$div = $divs->item($i);
				$div->removeAttribute('data-role');
				$div->removeAttribute('data-theme');
				$div->removeAttribute('style');
				$div->removeAttribute('data-icon');
				$div->removeAttribute('data-iconpos');
				$div->removeAttribute('onclick');
				$div->removeAttribute('data-state');
			}
			
			$links = $xpath->evaluate("/html/body//a");
			
			for ($i = 0; $i < $links->length; $i++) {
				$link = $links->item($i);
				$link->removeAttribute('data-inline');
				$link->removeAttribute('data-role');
				$link->removeAttribute('data-theme');
				$link->removeAttribute('style');
				$link->removeAttribute('data-icon');
				$link->removeAttribute('data-iconpos');
				$link->removeAttribute('onclick');
			}
			
			$uls = $xpath->evaluate("/html/body//ul");
			
			for ($i = 0; $i < $uls->length; $i++) {
				$ul = $uls->item($i);
				$ul->removeAttribute('data-inline');
				$ul->removeAttribute('data-role');
				$ul->removeAttribute('data-theme');
				$ul->removeAttribute('data-inset');
				$ul->removeAttribute('style');
				$ul->removeAttribute('data-icon');
				$ul->removeAttribute('data-iconpos');
				$ul->removeAttribute('onclick');
			}
			
			$htmls = $xpath->evaluate("/html");
			
			for ($i = 0; $i < $htmls->length; $i++) {
				$h = $htmls->item($i);
				$h->removeAttribute('dir');
				$h->removeAttribute('lang');
			}
			
			$text = $dom->saveHTML();
		}catch(Exception $e){
			$text = $html;
		}
	}else{
		$text = $html;
	}
	
	$text = preg_replace(
	  array(
	  	// Remove invisible content
	  	'@<meta[^>]*?>@siu',
	  	'@<link[^>]*?>@siu',
	  	'@<form[^>]*?>.*?</form>@siu',
	    '@<style[^>]*?>.*?</style>@siu',
	    '@<script[^>]*?.*?</script>@siu',
	    '@<object[^>]*?.*?</object>@siu',
	    '@<embed[^>]*?.*?</embed>@siu',
	    '@<applet[^>]*?.*?</applet>@siu',
	    '@<noframes[^>]*?.*?</noframes>@siu',
			'@<iframe[^>]*?.*?</iframe>@siu',
	    '@<noscript[^>]*?.*?</noscript>@siu',
	    '@<noembed[^>]*?.*?</noembed>@siu',
			// Remove visible content
			'@<img[^>]*?>@siu',
	  	// Add line breaks before and after blocks
	    '@</?((address)|(blockquote)|(center)|(del))@iu',
	    '@</?((div)|(h[1-9])|(ins)|(isindex)|(p)|(pre))@iu',
	    '@</?((dir)|(dl)|(dt)|(dd)|(li)|(menu)|(ol)|(ul))@iu',
	    '@</?((table)|(th)|(td)|(caption))@iu',
	    '@</?((form)|(button)|(fieldset)|(legend)|(input))@iu',
	    '@</?((label)|(select)|(optgroup)|(option)|(textarea))@iu',
	    '@</?((frameset)|(frame)|(iframe))@iu',
	  ),
	  array(
	    ' ',' ',' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ',
	    "\n\$0", "\n\$0", "\n\$0", "\n\$0", "\n\$0", "\n\$0",
	    "\n\$0", "\n\$0",
	  ),
	  $text );
  //If it is a websitez template, run the basic device stylesheet
  if($websitez_preinstalled_templates == "true")
  	$text = str_replace("</head>","<link rel='stylesheet' href='".get_bloginfo('stylesheet_directory')."/basic-device.css' />\n</head>\n",$text);
	
	$text = preg_replace('/\s\s+/', '', $text);
  $text = preg_replace('/<!--(.*?)-->/', '', $text);
  $text = preg_replace('/\n/', '', $text);
		
	return $text;
}

/*
When in the admin area, this will alert the admin if the plugin is not installed properly
*/
function websitez_checkInstalled(){
	global $wpdb,$table_prefix,$websitez_free_version;
	$table = $table_prefix."options";
	if(!get_option(WEBSITEZ_ADVANCED_THEME)){
		if($websitez_free_version == true){
			add_action('admin_notices', create_function( '', "echo '<div class=\"error\"><p>".WEBSITEZ_PLUGIN_NAME." was unable to install correctly. Please try deactivating and then activating this plugin again.</p><p><strong>If you still have trouble, please contact support@websitez.com</strong></p></div>';" ) );
		}else{
			add_action('admin_notices', create_function( '', "echo '<div class=\"error\"><p>".WEBSITEZ_PLUGIN_NAME." was unable to install correctly. This domain is not authorized to use this plugin.</p><p><strong>Please contact support@websitez.com</strong></p></div>';" ) );
		}
	}
}

/*
Change where it looks for themes on the frond end
*/
function websitez_setThemeFolderFront(){
	return plugin_dir_url(__FILE__).'/themes';
}

/*
Change where it looks for themes
*/
function websitez_setThemeFolder(){
	return WEBSITEZ_PLUGIN_DIR.'/themes';
}

/*
The theme set here is used if it is a mobile device
*/
function websitez_setTheme($theme){
	$GLOBALS['websitez_template_name'] = $theme;
}

/*
The theme retrieved here is used if it is a mobile device
*/
function websitez_getTheme(){
	return $GLOBALS['websitez_template_name'];
}

/*
Lets get this party started
*/
function websitez_check_and_act_mobile(){
	global $table_prefix, $wpdb, $websitez_free_version, $websitez_preinstalled_templates, $requestingDevice;
	
	$mobile_device = websitez_detect_mobile_device();
	//Set the detection
	websitez_set_mobile_device($mobile_device);

	//Is it a mobile device?
	if($mobile_device['status'] == true || $mobile_device['status'] == "1"){
		//Record a mobile visit only on the regular site and if it is enabled
		$websitez_record_stats = get_option(WEBSITEZ_RECORD_STATS_NAME);
		$websitez_preinstalled_templates = get_option(WEBSITEZ_USE_PREINSTALLED_THEMES_NAME);
		$websitez_redirect_mobile_visitor = get_option(WEBSITEZ_REDIRECT_MOBILE_VISITORS_NAME);
		$websitez_disable_plugin = get_option(WEBSITEZ_DISABLE_PLUGIN_NAME);
		if($websitez_record_stats == "true" && !is_feed() && !is_admin()){
			$insert = $wpdb->insert(WEBSITEZ_STATS_TABLE, array( 'data' => serialize($_SERVER), 'device_type' => $mobile_device['type'], 'created_at' => date("Y-m-d H:i:s") ) );
		}
		
		/*
		This will disable redirecting a mobile user or showing a mobile theme, but still provide detection.
		*/
		if($websitez_disable_plugin=="true"):
			return;
		endif;
		
		if($websitez_redirect_mobile_visitor=="true"):
			$websitez_redirect_mobile_visitor_website = get_option(WEBSITEZ_REDIRECT_MOBILE_VISITORS_WEBSITE_NAME);
			header("Location: ".$websitez_redirect_mobile_visitor_website);
			exit();
		endif;

		if($mobile_device['type'] == "1"){ //Mobile device
			$option = get_option(WEBSITEZ_ADVANCED_THEME);
			if(($websitez_preinstalled_templates == "false" && is_dir(ABSPATH.'/wp-content/themes/'.$option)) || ($websitez_preinstalled_templates == "true" && is_dir(WEBSITEZ_PLUGIN_DIR.'/themes/'.$option)) && strlen($option) > 0) {
				//This logic switches the theme and modifies the head/footer to give the user the ability to switch back to the full site
				websitez_setTheme($option);
				add_action('wp', 'websitez_advanced_buffer', 10, 0);
				add_filter("the_content", "websitez_filterContentAdvanced");
				add_action('wp_footer', 'websitez_web_footer');
				add_action('wp_head', 'websitez_web_head');
				add_filter('wp', 'websitez_redirect');
				return true;
			}
		}else if($mobile_device['type'] == "0" && isset($_COOKIE['websitez_mobile_detector_fullsite'])){
			//If this is true, it is a mobile user, but they elected to view the full site.
			//We should give them the option to switch back
			add_action('wp_footer', 'websitez_web_footer_mobile');
			add_action('wp_head', 'websitez_web_head_mobile');
			//We want to return false so that the currently installed template is shown
			return false;
		}
	}else{
		//If it is the free version, add attribution
		if(get_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME) == "true"){
			add_action('wp_footer', 'websitez_web_footer_standard');
		}
		//This means it is not a mobile device
	}
	return false;
}

function websitez_redirect(){
	$websitez_options = unserialize(get_option('websitez-options'));
	$page = $websitez_options['general']['mobile_home_page'];
	if($page && is_front_page() && is_numeric($page)){
		header("HTTP/1.1 301 Moved Permanently");
		$query = $_SERVER['QUERY_STRING'];
		if(strlen($query) > 0){
			header('Location: '.get_permalink($page).'?'.$_SERVER['QUERY_STRING']);
		}else{
			header('Location: '.get_permalink($page));
		}
 		die;
	}
}

function websitez_filterContentStandard($content){
	//Remove all images
	$content = preg_replace("/<img[^>]+\>/i", "", $content);
	return $content;
}

function websitez_filterContentAdvanced($content){
	//For now, do not filter anything, possibly filter HTML5 tags such as canvas
	return $content;
}

function websitez_web_footer_standard(){
	echo "<div class='websitez-footer' style='font-size: 1em; text-align: center; padding: 4px 0px;'>\n<p>".websitez_kpr()."</p>\n</div>\n";
}

/*
Attribution and ability to switch between mobile and full site
*/
function websitez_web_footer(){
	global $websitez_free_version;
	if($websitez_free_version == true){
		if(get_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME) == "true"):
			echo "<div class='websitez-footer'>\n
	<p>".websitez_kpr()."&nbsp;&nbsp;&nbsp;<a href='' onClick='websitez_setFullSite()' rel='nofollow'>View Full Site</a></p>\n
	</div>\n";
		else:
			echo "<div class='websitez-footer'>\n
	<p><a href='' onClick='websitez_setFullSite()' rel='nofollow'>View Full Site</a></p>\n
	</div>\n";
		endif;
	}else{
		if(get_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME) == "true"):
			echo "<div class='websitez-footer'>\n
	<p>".websitez_kpr()."&nbsp;&nbsp;&nbsp;<a href='' onClick='websitez_setFullSite()' rel='nofollow'>View Full Site</a></p>\n
	</div>\n";
		else:
			echo "<div class='websitez-footer'>\n
	<p><a href='' onClick='websitez_setFullSite()' rel='nofollow'>View Full Site</a></p>\n
	</div>\n";
		endif;
	}
}

/*
Attribution and ability to switch between mobile and full site
*/
function websitez_web_footer_mobile(){
	global $websitez_free_version;
	if($websitez_free_version == true){
		if(get_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME) == "true"):
			echo "<div class='websitez-footer-mobile'>\n
	<p>".websitez_kpr()."&nbsp;&nbsp;&nbsp;<a href='' onClick='websitez_setMobileSite()' rel='nofollow'>View Mobile Site</a></p>\n
	</div>\n";
		else:
			echo "<div class='websitez-footer-mobile'>\n
	<p><a href='' onClick='websitez_setMobileSite()' rel='nofollow'>View Mobile Site</a></p>\n
	</div>\n";
		endif;
	}else{
		if(get_option(WEBSITEZ_SHOW_ATTRIBUTION_NAME) == "true"):
			echo "<div class='websitez-footer-mobile'>\n
	<p>".websitez_kpr()."&nbsp;&nbsp;&nbsp;<a href='' onClick='websitez_setMobileSite()' rel='nofollow'>View Mobile Site</a></p>\n
	</div>\n";
		else:
			echo "<div class='websitez-footer-mobile'>\n
	<p><a href='' onClick='websitez_setMobileSite()' rel='nofollow'>View Mobile Site</a></p>\n
	</div>\n";
		endif;
	}
}

/*
Attribution and ability to switch between mobile and full site
*/
function websitez_web_head(){
	echo "<script type='text/javascript'>\n
	function websitez_setFullSite(){\n
		c_name = 'websitez_mobile_detector_fullsite';\n
		value = '1';\n
		expiredays = '1';\n
		var exdate=new Date();\n
		exdate.setDate(exdate.getDate()+expiredays);\n
		document.cookie=c_name+ '=' +escape(value)+((expiredays==null) ? '' : ';expires='+exdate.toUTCString());\n
		window.location.reload();\n
	}\n
	</script>\n";
}

/*
Attribution and ability to switch between mobile and full site
*/
function websitez_web_head_mobile(){
	echo "<script type='text/javascript'>\n
	function websitez_setMobileSite(){\n
		websitez_setCookie('websitez_mobile_detector','',-1);
		websitez_setCookie('websitez_mobile_detector_fullsite','',-1);
		window.location.reload();\n
	}\n
	function websitez_setCookie(c_name,value,expiredays){\n
		var exdate=new Date();\n
		exdate.setDate(exdate.getDate()+expiredays);\n
		document.cookie=c_name+ '=' +escape(value)+((expiredays==null) ? '' : ';expires='+exdate.toUTCString());\n
	}\n
	</script>\n";
}

/*
Returns an array of information about the device
*/
function websitez_detect_mobile_device(){
	global $wpdb, $requestingDevice;
	
	//Speaks for itself
  $user_agent = $_SERVER['HTTP_USER_AGENT'];

	//Checks to see if this has already been detected as a device.
	//$check = websitez_check_previous_detection($user_agent);

	if($check){
		$check['details'] = $requestingDevice;
		return $check;
	}

	//Innocent until proven guilty
	$mobile_browser = false;
	//This can also be used to detect a mobile device
  $accept = $_SERVER['HTTP_ACCEPT'];
	//Type of phone
	$mobile_browser_type = "0"; //0 - PC, 1 - Smart Phone, 2- Standard Phone
	
	$websitez_options = unserialize(get_option('websitez-options'));
	
	/*
	WURFL
	*/
	$wurflConfigFile = WURFL_RESOURCES_DIR . 'wurfl-config.xml';
	// Create WURFL Configuration from an XML config file
	$wurflConfig = new WURFL_Configuration_XmlConfig($wurflConfigFile);
	// Create a WURFL Manager Factory from the WURFL Configuration
	$wurflManagerFactory = new WURFL_WURFLManagerFactory($wurflConfig);
	// Create a WURFL Manager ($wurflManager is a WURFL_WURFLManager object)
	$wurflManager = $wurflManagerFactory->create();
	// Get device information
	$requestingDevice = $wurflManager->getDeviceForHttpRequest($_SERVER);
	
	if($requestingDevice->getCapability('is_wireless_device') == 'true'):
		if($requestingDevice->getCapability('is_tablet') == 'true'):
			if($websitez_options['general']['display_to_tablet'] == 'no'):
				$mobile_browser = false;
				$mobile_browser_type = "0";
			else:
				$mobile_browser = true;
				$mobile_browser_type = "1"; //Smart Phone
			endif;
		else:
			$mobile_browser = true;
			$mobile_browser_type = "1"; //Smart Phone
		endif;
	elseif(isset($_GET['websitez-mobile'])):
		$mobile_browser = true;
		$mobile_browser_type = "1"; //Smart Phone
	endif;
	/*
	END WURFL
	*/
	
	//Set a persistent client-side value to avoid having to detect again for this visitor
	websitez_set_previous_detection($mobile_browser,$mobile_browser_type,$user_agent);
	return array('status'=>$mobile_browser,'type'=>$mobile_browser_type,'details'=>$requestingDevice);
}

/*
If it is a mobile device, lets try and remember to avoid having to detect it again
*/
function websitez_set_previous_detection($status,$type,$user_agent){
	if($status){
		//This is set to prevent caching mechanisms such as W3 total cache from caching the mobile page
		setcookie("websitez_is_mobile", "true", time()+3600, "/");
	}
	setcookie("websitez_mobile_detector", $status."|".$type."|".md5($user_agent), time()+3600, "/");
}

/*
Check to see if this mobile device has been previously detected
*/
function websitez_check_previous_detection($user_agent = null){
	if(isset($_COOKIE['websitez_mobile_detector_fullsite']) && isset($_COOKIE['websitez_mobile_detector'])){
		$obj = explode("|",$_COOKIE['websitez_mobile_detector']);
		//Check to see if their user agent has changed
		if($obj[2] != md5($user_agent)){
			//Their user agent hash doesn't match, which means they changed their
			//user agent somehow. Usually this is with a user agent switcher.
			return false;
		}else{
			//Returning a 0 will show the desktop version aka the 'fullsite'
			//This is executed if the user elected to view the 'fullsite' version
			return array('status'=>$obj[0],'type'=>'0');
		}
	}else if(isset($_COOKIE['websitez_mobile_detector'])){
		$obj = explode("|",$_COOKIE['websitez_mobile_detector']);
		//Check to see if their user agent has changed
		if($obj[2] != md5($user_agent)){
			//Their user agent hash doesn't match, which means they changed their user agent
			return false;
		}else{
			return array('status'=>$obj[0],'type'=>$obj[1]);
		}
	}else{
		return false;
	}
}

/*
Return the current themes in wp-content/themes
*/
function websitez_get_current_themes(){
	$websitez_preinstalled_templates = get_option(WEBSITEZ_USE_PREINSTALLED_THEMES_NAME);
	
	if($websitez_preinstalled_templates == "true"){
		$path = WEBSITEZ_PLUGIN_DIR.'/themes';
		return $wp_themes = websitez_get_themes($path);
	}else{
		if(!function_exists('get_themes'))
			return null;

		return $wp_themes = get_themes();
	}
}

/*
Information about the types of devices that can be detected
*/
function websitez_get_mobile_types(){
	return array(array('name'=>'Basic Mobile Device','option'=>WEBSITEZ_BASIC_THEME),array('name'=>'Advanced Mobile Device','option'=>WEBSITEZ_ADVANCED_THEME));
}

function websitez_get_themes($path = null, $only_mobile = false) {
	global $wp_themes, $wp_broken_themes, $wp_theme_directories;

	/*
	Register the default root as a theme directory 
	This was working, but occasionally would load the regular themes in the wp-content/themes
	Oddly enough this seemed to be sporadic.
	*/
	//register_theme_directory( $path );
	
	//Empty out the directory array and add the plugin dir
	if($only_mobile == true){
		$current_theme_directories = $wp_theme_directories;
		$wp_theme_directories = array($path);
	}

	if (!function_exists('search_theme_directories') || !$theme_files = search_theme_directories())
		return false;

	asort( $theme_files );

	$wp_themes = array();

	foreach ( (array) $theme_files as $theme_file ) {
		$theme_root = $theme_file['theme_root'];
		$theme_file = $theme_file['theme_file'];

		if ( !is_readable("$theme_root/$theme_file") ) {
			$wp_broken_themes[$theme_file] = array('Name' => $theme_file, 'Title' => $theme_file, 'Description' => __('File not readable.'));
			continue;
		}

		$theme_data = get_theme_data("$theme_root/$theme_file");

		$name        = $theme_data['Name'];
		$title       = $theme_data['Title'];
		$description = wptexturize($theme_data['Description']);
		$version     = $theme_data['Version'];
		$author      = $theme_data['Author'];
		$template    = $theme_data['Template'];
		$stylesheet  = dirname($theme_file);

		$screenshot = false;
		foreach ( array('png', 'gif', 'jpg', 'jpeg') as $ext ) {
			if (file_exists("$theme_root/$stylesheet/screenshot.$ext")) {
				$screenshot = "screenshot.$ext";
				break;
			}
		}

		if ( empty($name) ) {
			$name = dirname($theme_file);
			$title = $name;
		}

		$parent_template = $template;

		if ( empty($template) ) {
			if ( file_exists("$theme_root/$stylesheet/index.php") )
				$template = $stylesheet;
			else
				continue;
		}

		$template = trim( $template );

		if ( !file_exists("$theme_root/$template/index.php") ) {
			$parent_dir = dirname(dirname($theme_file));
			if ( file_exists("$theme_root/$parent_dir/$template/index.php") ) {
				$template = "$parent_dir/$template";
				$template_directory = "$theme_root/$template";
			} else {
				/**
				 * The parent theme doesn't exist in the current theme's folder or sub folder
				 * so lets use the theme root for the parent template.
				 */
				if ( isset($theme_files[$template]) && file_exists( $theme_files[$template]['theme_root'] . "/$template/index.php" ) ) {
					$template_directory = $theme_files[$template]['theme_root'] . "/$template";
				} else {
					if ( empty( $parent_template) )
						$wp_broken_themes[$name] = array('Name' => $name, 'Title' => $title, 'Description' => __('Template is missing.'), 'error' => 'no_template');
					else
						$wp_broken_themes[$name] = array('Name' => $name, 'Title' => $title, 'Description' => sprintf( __('The parent theme is missing. Please install the "%s" parent theme.'),  $parent_template ), 'error' => 'no_parent', 'parent' => $parent_template );
					continue;
				}

			}
		} else {
			$template_directory = trim( $theme_root . '/' . $template );
		}

		$stylesheet_files = array();
		$template_files = array();

		$stylesheet_dir = @ dir("$theme_root/$stylesheet");
		if ( $stylesheet_dir ) {
			while ( ($file = $stylesheet_dir->read()) !== false ) {
				if ( !preg_match('|^\.+$|', $file) ) {
					if ( preg_match('|\.css$|', $file) )
						$stylesheet_files[] = "$theme_root/$stylesheet/$file";
					elseif ( preg_match('|\.php$|', $file) )
						$template_files[] = "$theme_root/$stylesheet/$file";
				}
			}
			@ $stylesheet_dir->close();
		}

		$template_dir = @ dir("$template_directory");
		if ( $template_dir ) {
			while ( ($file = $template_dir->read()) !== false ) {
				if ( preg_match('|^\.+$|', $file) )
					continue;
				if ( preg_match('|\.php$|', $file) ) {
					$template_files[] = "$template_directory/$file";
				} elseif ( is_dir("$template_directory/$file") ) {
					$template_subdir = @ dir("$template_directory/$file");
					if ( !$template_subdir )
						continue;
					while ( ($subfile = $template_subdir->read()) !== false ) {
						if ( preg_match('|^\.+$|', $subfile) )
							continue;
						if ( preg_match('|\.php$|', $subfile) )
							$template_files[] = "$template_directory/$file/$subfile";
					}
					@ $template_subdir->close();
				}
			}
			@ $template_dir->close();
		}

		//Make unique and remove duplicates when stylesheet and template are the same i.e. most themes
		$template_files = array_unique($template_files);
		$stylesheet_files = array_unique($stylesheet_files);

		$template_dir = dirname($template_files[0]);
		$stylesheet_dir = dirname($stylesheet_files[0]);

		if ( empty($template_dir) )
			$template_dir = '/';
		if ( empty($stylesheet_dir) )
			$stylesheet_dir = '/';

		// Check for theme name collision.  This occurs if a theme is copied to
		// a new theme directory and the theme header is not updated.  Whichever
		// theme is first keeps the name.  Subsequent themes get a suffix applied.
		// The Default and Classic themes always trump their pretenders.
		if ( isset($wp_themes[$name]) ) {
			if ( ('WordPress Default' == $name || 'WordPress Classic' == $name) &&
					 ('default' == $stylesheet || 'classic' == $stylesheet) ) {
				// If another theme has claimed to be one of our default themes, move
				// them aside.
				$suffix = $wp_themes[$name]['Stylesheet'];
				$new_name = "$name/$suffix";
				$wp_themes[$new_name] = $wp_themes[$name];
				$wp_themes[$new_name]['Name'] = $new_name;
			} else {
				$name = "$name/$stylesheet";
			}
		}

		$theme_roots[$stylesheet] = str_replace( WP_CONTENT_DIR, '', $theme_root );
		$wp_themes[$name] = array(
			'Name' => $name,
			'Title' => $title,
			'Description' => $description,
			'Author' => $author,
			'Author Name' => $theme_data['AuthorName'],
			'Author URI' => $theme_data['AuthorURI'],
			'Version' => $version,
			'Template' => $template,
			'Stylesheet' => $stylesheet,
			'Template Files' => $template_files,
			'Stylesheet Files' => $stylesheet_files,
			'Template Dir' => $template_dir,
			'Stylesheet Dir' => $stylesheet_dir,
			'Status' => $theme_data['Status'],
			'Screenshot' => $screenshot,
			'Tags' => $theme_data['Tags'],
			'Theme Root' => $theme_root,
			'Theme Root URI' => str_replace( WP_CONTENT_DIR, content_url(), $theme_root ),
		);
	}

	unset($theme_files);

	/* Store theme roots in the DB */
	if ( function_exists('get_site_transient') && get_site_transient( 'theme_roots' ) != $theme_roots )
		set_site_transient( 'theme_roots', $theme_roots, 7200 ); // cache for two hours
	unset($theme_roots);

	/* Resolve theme dependencies. */
	$theme_names = array_keys( $wp_themes );
	foreach ( (array) $theme_names as $theme_name ) {
		$wp_themes[$theme_name]['Parent Theme'] = '';
		if ( $wp_themes[$theme_name]['Stylesheet'] != $wp_themes[$theme_name]['Template'] ) {
			foreach ( (array) $theme_names as $parent_theme_name ) {
				if ( ($wp_themes[$parent_theme_name]['Stylesheet'] == $wp_themes[$parent_theme_name]['Template']) && ($wp_themes[$parent_theme_name]['Template'] == $wp_themes[$theme_name]['Template']) ) {
					$wp_themes[$theme_name]['Parent Theme'] = $wp_themes[$parent_theme_name]['Name'];
					break;
				}
			}
		}
	}
	
	//Empty out the directory array and add the plugin dir
	if($only_mobile == true){
		$wp_theme_directories = $current_theme_directories;
	}
	
	return $wp_themes;
}

/*
Will return a link to place depending on first char of the page filename
*/
function websitez_kpr(){
	// phrase 3 should be your primary keyphrase, as it will come up with index.html
	
	$kpr_phrase = array(
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile</a>', //0
		'<a href="http://websitez.com" title="WordPress Mobile Themes">WordPress Mobile Themes</a>', //1
		'<a href="http://websitez.com/products-page/featured/wordpress-mobile-plugin/" title="WordPress Mobile Plugin">WordPress Mobile Plugin</a>', //2
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile</a>', //3
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile</a>', //4
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile</a>', //5
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile Plugins</a>', //6
		'<a href="http://websitez.com" title="WordPress Mobile Themes">WordPress Mobile Themes</a>', //7
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile</a>', //8
		'<a href="http://websitez.com" title="WordPress Mobile Plugins">WordPress Mobile Plugins</a>', //9
		'<a href="http://websitez.com" title="WordPress Mobile">WordPress Mobile</a>', //10
	);
	##############################
	# DO NOT EDIT BELOW THIS LINE
	##############################

	// unset variables to get a clean start
	unset($kpr_explode);
	unset($internal_page_filename);
	unset($kpr_char);
	unset($kpr_num);

	// get the page's filename
	$kpr_explode = explode('/', $_SERVER["REQUEST_URI"]);
	if(count($kpr_explode) >=2){
		if($kpr_explode[count($kpr_explode)-1] != ""){
			$internal_page_filename = strtolower($kpr_explode[count($kpr_explode)-1]);
		}else if($kpr_explode[count($kpr_explode)-2] != ""){
			$internal_page_filename = strtolower($kpr_explode[count($kpr_explode)-2]);
		}else{
			$internal_page_filename = "index";
		}
	}else{
		$internal_page_filename = "index";
	}

	// get the first letter of the page's filename and convert it to ascii
	$kpr_char = substr($internal_page_filename, 0, 1);
	$kpr_num = ord($kpr_char);

	// display the appropriate phrase
	if ($kpr_num <= 96) // caps, numbers, some punctuation, and most non printable chars
	{
		return $kpr_phrase[0];
	}
	else if ( ($kpr_num >= 97) && ($kpr_num <= 99) ) // a - c
	{
		return $kpr_phrase[1];
	}
	else if ( ($kpr_num >= 100) && ($kpr_num <= 102) ) // d - f
	{
		return $kpr_phrase[2];
	}
	else if ( ($kpr_num >= 103) && ($kpr_num <= 105) ) // g - i
	{
		return $kpr_phrase[3];
	}
	else if ( ($kpr_num >= 106) && ($kpr_num <= 108) ) // j - l
	{
		return $kpr_phrase[4];
	}
	else if ( ($kpr_num >= 109) && ($kpr_num <= 111) ) // m - o
	{
		return $kpr_phrase[5];
	}
	else if ( ($kpr_num >= 112) && ($kpr_num <= 114) ) // p - r
	{
		return $kpr_phrase[6];
	}
	else if ( ($kpr_num >= 115) && ($kpr_num <= 117) ) // s - u
	{
		return $kpr_phrase[7];
	}
	else if ( ($kpr_num >= 118) && ($kpr_num <= 120) ) // v - x
	{
		return $kpr_phrase[8];
	}
	else if ($kpr_num >= 121) // y +
	{
		return $kpr_phrase[9];
	}
	else // catchall for anything that slipped through the cracks
	{
		return $kpr_phrase[10];
	}
}


/*
Perform CURL
*/
function websitez_remote_request($host,$path){
	$fp = curl_init($host);
	curl_setopt($fp, CURLOPT_POST, true);
	curl_setopt($fp, CURLOPT_POSTFIELDS, $path);
	curl_setopt($fp, CURLOPT_RETURNTRANSFER, true);
	$page = curl_exec($fp);
	curl_close($fp);
	
	return $page;
}
?>